%{!?python2_shortver: %global python2_shortver %(%{__python2} -c 'import sys; print(str(sys.version_info.major) + "." + str(sys.version_info.minor))')}
%{!?python3_shortver: %global python3_shortver %(%{__python3} -c 'import sys; print(str(sys.version_info.major) + "." + str(sys.version_info.minor))')}

%global oname cclib

Name:		python-%{oname}
Version:	1.3.2
Release:	8%{?dist}
Summary:	A library for processing results of computational chemistry packages
License:	LGPLv2+
URL:		https://github.com/cclib/cclib
Source0:	https://github.com/%{oname}/%{oname}/archive/v%{version}.tar.gz
BuildArch:	noarch

BuildRequires:	python2-devel
BuildRequires:	python3-devel
# For test phase
BuildRequires:	numpy
BuildRequires:	python3-numpy

%description
cclib is an open source library, written in Python, for parsing and
interpreting the results of computational chemistry packages. The current
version, cclib 0.9, parses output files from ADF, GAMESS (US), GAMESS-UK,
Gaussian, Jaguar, Molpro, ORCA and PC GAMESS.


%package -n python2-%{oname}
Summary:	%{summary}
%{?python_provide:%python_provide python2-%{oname}}
# Needed for operation
Requires:	numpy
# Extra stuff
Requires:	PyQt4
Requires:	vtk-python

%description -n python2-%{oname}
cclib is an open source library, written in Python, for parsing and
interpreting the results of computational chemistry packages. The current
version, cclib 0.9, parses output files from ADF, GAMESS (US), GAMESS-UK,
Gaussian, Jaguar, Molpro, ORCA and PC GAMESS.

%package -n python3-%{oname}
Summary:	%{summary}
%{?python_provide:%python_provide python3-%{oname}}
Requires:	python3-numpy

%description -n python3-%{oname}
cclib is an open source library, written in Python, for parsing and
interpreting the results of computational chemistry packages. The current
version, cclib 0.9, parses output files from ADF, GAMESS (US), GAMESS-UK,
Gaussian, Jaguar, Molpro, ORCA and PC GAMESS.

This is the python3 version of the library.

%prep
%setup -q -c -n %{oname}-%{version} -T
tar zxf %{SOURCE0}
chmod u=rwX -R %{oname}-%{version}
mv %{oname}-%{version}/* .
# Fix permissions
find . -type f -exec chmod 644 {} \;
# Fix line endings
for file in PKG-INFO test/*.py; do
    sed -e 's|\r||g' $file > $file.new &&
    touch -r $file $file.new &&
    mv $file.new $file
done
# Fix encodings
for f in THANKS CHANGELOG; do
    iconv -f ISO-8859-1 -t utf8 $f > $f.new && \
	touch -r $f $f.new && \
	mv $f.new $f
done

# Add file encodings for compilation under python-2.7
# https://github.com/langner/cclib/commit/9fddf44edaf9a139fd83c5bbb06127ec4107f0f4
# https://github.com/cclib/cclib/issues/160
# sed -i '1 i\# -*- coding: utf-8 -*-'  src/cclib/method/lpa.py

%build
%py2_build
%py3_build

%install
%py2_install
mv %{buildroot}/%{_bindir}/cda \
    %{buildroot}/%{_bindir}/python2-cda
mv %{buildroot}/%{_bindir}/ccget \
    %{buildroot}/%{_bindir}/python2-ccget

%py3_install

# rename binaries, make compat symlinks
pushd %{buildroot}%{_bindir}
for i in cda-{2,%{?python2_shortver}}; do
    ln -s python2-cda $i
done

for i in ccget-{2,%{?python2_shortver}}; do
    ln -s python2-ccget $i
done


for i in cda-{3,%{?python3_shortver}}; do
    ln -s cda $i
done

for i in ccget-{3,%{?python3_shortver}}; do
    ln -s ccget $i
done
popd

# Test phase needs installed python-cclib 
%check
#pushd test
#PYTHONPATH=../build/lib python testall.py
#popd

# disable python3 tests temporarily
# https://github.com/cclib/cclib/issues/213 - fixed
# test using python3
#pushd test
#PYTHONPATH=../build/lib python3 testall.py
#popd

%files -n python2-%{oname}
%license LICENSE
%doc ANNOUNCE CHANGELOG README THANKS
%{python2_sitelib}/%{oname}/
%{python2_sitelib}/%{oname}-*.egg-info
%{_bindir}/python2-*
%{_bindir}/cda-2*
%{_bindir}/ccget-2*

%files -n python3-%{oname}
%doc ANNOUNCE CHANGELOG README THANKS
%{python3_sitelib}/%{oname}/
%{python3_sitelib}/%{oname}-*.egg-info
%{_bindir}/cda
%{_bindir}/cda-3*
%{_bindir}/ccget
%{_bindir}/ccget-3*


%changelog
* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 1.3.2-5
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-4
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Mon Feb 15 2016 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 1.3.2-3
- Temporarily disable tests for fixing FTBFS
- Fixes bug #1307899

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Dec 07 2015 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 1.3.2-1
- Update to maintenance update 1.3.2
- re-enable python3 tests (fixed upstream)

* Sun Nov 15 2015 Eduardo Mayorga Téllez <mayorga@fedoraproject.org> - 1.3.1-5
- Move binaries to the right package
- Remove deprecated tags and replace deprecated macros
- Build python2 and python3 packages in the same directory
- Use %%license macro

* Sat Nov 14 2015 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 1.3.1-4
- Disable python3 tests temporarily
- upstream issue filed

* Tue Nov 10 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-3
- Rebuilt for https://fedoraproject.org/wiki/Changes/python3.5

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Feb 14 2015 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 1.3.1-1
- Update to version 1.3.1

* Thu Jan 22 2015 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 1.3-1
- Update to version 1.3

* Sun Jul 13 2014 Mukundan Ragavan <nonamedotc@gmail.com> - 1.2-2
- Added python3 package

* Fri Jun 13 2014 Mukundan Ragavan <nonamedotc@fedoraproject.org> - 1.2-1
- Updated to 1.2
- Changed URL and Source0 to github links
- Added sed lines to add file encoding for compiling under python-2.7

* Fri Jun 13 2014 Susi Lehtola <jussilehtola@fedoraproject.org> - 1.1-1
- Update to 1.1.

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Mar 15 2011 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.0.1-1
- Update to 1.0.1.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jul 24 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.0-2
- Workaround bad permissions in tarball causing FTBFS.

* Fri Mar 12 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.0-1
- Update to 1.0.

* Wed Feb 24 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 1.0a-1
- Update to 1.0a.

* Sun Feb 14 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.91-7
- Bump release.

* Fri Jul 31 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.91-6
- Drop extra requires by request of upstream.

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.91-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat May 02 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.91-4
- Put everything in main package instead.

* Fri Apr 24 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.91-3
- Branched supplementary Requires metapackage.

* Thu Apr 23 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.91-2
- Added BR: numpy and Requires: numpy.
- Removed test/ from %%doc.

* Thu Apr 23 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.91-1
- First release.
